@@ -32,13 +32,6 @@
 # define VTKFILTERSSTATISTICS_NO_DEPRECATED
 #endif
 
-/* AutoInit implementations.  */
-#if defined(vtkFiltersStatistics_INCLUDE)
-# include vtkFiltersStatistics_INCLUDE
-#endif
-#if defined(vtkFiltersStatistics_AUTOINIT)
-# include "vtkAutoInit.h"
-VTK_AUTOINIT(vtkFiltersStatistics)
-#endif
+
 
 #endif
